# coding: utf-8

"""
    Gmail API

    The Gmail API lets you view and manage Gmail mailbox data like threads, messages, and labels.

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ImapSettings(BaseModel):
    """
    IMAP settings for an account.
    """ # noqa: E501
    auto_expunge: Optional[StrictBool] = Field(default=None, description="If this value is true, Gmail will immediately expunge a message when it is marked as deleted in IMAP. Otherwise, Gmail will wait for an update from the client before expunging messages marked as deleted.", alias="autoExpunge")
    enabled: Optional[StrictBool] = Field(default=None, description="Whether IMAP is enabled for the account.")
    expunge_behavior: Optional[StrictStr] = Field(default=None, description="The action that will be executed on a message when it is marked as deleted and expunged from the last visible IMAP folder.", alias="expungeBehavior")
    max_folder_size: Optional[StrictInt] = Field(default=None, description="An optional limit on the number of messages that an IMAP folder may contain. Legal values are 0, 1000, 2000, 5000 or 10000. A value of zero is interpreted to mean that there is no limit.", alias="maxFolderSize")
    __properties: ClassVar[List[str]] = ["autoExpunge", "enabled", "expungeBehavior", "maxFolderSize"]

    @field_validator('expunge_behavior')
    def expunge_behavior_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['expungeBehaviorUnspecified', 'archive', 'trash', 'deleteForever']):
            raise ValueError("must be one of enum values ('expungeBehaviorUnspecified', 'archive', 'trash', 'deleteForever')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ImapSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ImapSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "autoExpunge": obj.get("autoExpunge"),
            "enabled": obj.get("enabled"),
            "expungeBehavior": obj.get("expungeBehavior"),
            "maxFolderSize": obj.get("maxFolderSize")
        })
        return _obj


